from setuptools import setup


setup(
    name='felya1',
    version='0.1.0',
    description='A example Python package',    
    author='Ofelia Epremyan',
    install_requires=['numpy<1.16', 'matplotlib'],

)